==> foundation-2.6.1.tgz: package/VolumeStrike/VolumeStrike.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const VolumeStrike = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M60.416 35.232l-.022.022 1.923 1.924.031-.031c.025.026.042.057.067.083 4.39 4.39 6.071 10.47 5.059 16.163l7.868 7.868c4.384-10.269 2.403-22.629-5.964-30.995-.026-.026-.056-.042-.082-.067l.008-.008-1.924-1.923-.022.021a2.7 2.7 0 00-3.554.161l-.004-.004-.035.035-.003.002-.002.003-3.149 3.148-.003.002-.002.003-.225.225.023.022a2.697 2.697 0 00.012 3.346z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M78.868 17.089c-.026-.025-.056-.042-.082-.067l.008-.008-1.924-1.923-.022.022a2.696 2.696 0 00-3.553.161l-.004-.004-3.419 3.418.023.023a2.693 2.693 0 00.01 3.345l-.022.021.216.216 1.707 1.708.031-.031c.025.026.042.057.067.083 11.153 11.153 13.663 27.718 7.545 41.315l7.332 7.332c9.752-17.77 7.125-40.573-7.913-55.611zm-24.042 8.619h-.024a2.064 2.064 0 00-2.047-1.837 2.04 2.04 0 00-1.031.285l-.018-.032-8.558 4.941 11.679 11.679V25.708zM23.502 40.42H9.021v.04c-.012 0-.024-.003-.037-.003-.842 0-1.525.684-1.525 1.525v20.66c0 .842.683 1.524 1.525 1.524.013 0 .024-.003.037-.004v.041h14.482l11.524 6.653v-.031l16.548 9.555a2.071 2.071 0 003.252-1.698c0-.081-.015-.155-.024-.233h.024v-9.413L25.219 39.428l-1.717.992zm62.316 38.368L21.172 14.141l-.002.002-.016-.02a2.487 2.487 0 00-3.516 0c-.034.034-.058.074-.09.11l-3.458 3.476-.012.01a2.485 2.485 0 000 3.515l64.651 64.651.001-.001a2.486 2.486 0 003.507-.009l.004.004 3.432-3.449c.049-.042.103-.076.15-.123a2.488 2.488 0 00-.005-3.519z"
  }));
});
VolumeStrike.displayName = 'VolumeStrike';
export const VolumeStrikeDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/VolumeStrike/VolumeStrike.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var VolumeStrike = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M60.416 35.232l-.022.022 1.923 1.924.031-.031c.025.026.042.057.067.083 4.39 4.39 6.071 10.47 5.059 16.163l7.868 7.868c4.384-10.269 2.403-22.629-5.964-30.995-.026-.026-.056-.042-.082-.067l.008-.008-1.924-1.923-.022.021a2.7 2.7 0 00-3.554.161l-.004-.004-.035.035-.003.002-.002.003-3.149 3.148-.003.002-.002.003-.225.225.023.022a2.697 2.697 0 00.012 3.346z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M78.868 17.089c-.026-.025-.056-.042-.082-.067l.008-.008-1.924-1.923-.022.022a2.696 2.696 0 00-3.553.161l-.004-.004-3.419 3.418.023.023a2.693 2.693 0 00.01 3.345l-.022.021.216.216 1.707 1.708.031-.031c.025.026.042.057.067.083 11.153 11.153 13.663 27.718 7.545 41.315l7.332 7.332c9.752-17.77 7.125-40.573-7.913-55.611zm-24.042 8.619h-.024a2.064 2.064 0 00-2.047-1.837 2.04 2.04 0 00-1.031.285l-.018-.032-8.558 4.941 11.679 11.679V25.708zM23.502 40.42H9.021v.04c-.012 0-.024-.003-.037-.003-.842 0-1.525.684-1.525 1.525v20.66c0 .842.683 1.524 1.525 1.524.013 0 .024-.003.037-.004v.041h14.482l11.524 6.653v-.031l16.548 9.555a2.071 2.071 0 003.252-1.698c0-.081-.015-.155-.024-.233h.024v-9.413L25.219 39.428l-1.717.992zm62.316 38.368L21.172 14.141l-.002.002-.016-.02a2.487 2.487 0 00-3.516 0c-.034.034-.058.074-.09.11l-3.458 3.476-.012.01a2.485 2.485 0 000 3.515l64.651 64.651.001-.001a2.486 2.486 0 003.507-.009l.004.004 3.432-3.449c.049-.042.103-.076.15-.123a2.488 2.488 0 00-.005-3.519z"
  }));
});
VolumeStrike.displayName = 'VolumeStrike';
export var VolumeStrikeDimensions = {
  height: 100,
  width: 100
};
